# pyscan-tlk
Python wrappers for Thorlabs Kinesis dlls. 

# Contents

This package consists of 33 different python wrapper files for thorlabs kinesis instruments. Each wrapper file consists of nearly all c functions for the instrument, with the exception of those that require `SafeArray` types or failed to import from the dll files.  Examples of using these wrappers is shown in ./test_wrappers/ along with a simulation file. 

# Installation

Usage of this package requires installation of [Thorlabs Kinesis software]{https://www.thorlabs.com/newgrouppage9.cfm?objectgroup_id=10285} for Windows. 

pyscan_tlk is indexed on pypi.org and can be installed by 

`pip install pyscan_tlk`

Alternatively, this git repository can be cloned followed by an editable install (from within the folder where the repository was cloned) via

`pip install -e .`

# Contributions

Pull requests are welcome via merge request. For major changes, please open an issue first to discuss what you would like to change. Bugs may exist as the code was autogenerated by parsig the c '.h' files and documentation. 

For questions please contact: Andy Mounce amounce@sandia.gov

